# -*- coding: utf-8 -*-
from dataclasses import dataclass


@dataclass(frozen=True)
class NewEvent:
    type: str
    data: bytes
    metadata: bytes


@dataclass(frozen=True)
class RecordedEvent(NewEvent):
    stream_name: str
    stream_position: int
    commit_position: int



# -*- coding: utf-8 -*-
class EsdbClientException(Exception):
    pass


class GrpcError(EsdbClientException):
    pass


class ServiceUnavailable(GrpcError):
    pass


class DeadlineExceeded(GrpcError):
    pass


class StreamNotFound(EsdbClientException):
    pass


class ExpectedPositionError(EsdbClientException):
    pass



# -*- coding: utf-8 -*-
import sys
from typing import Iterable, List, Optional, Sequence, overload
from uuid import uuid4

from grpc import Call, Channel, RpcError, StatusCode
from typing_extensions import Literal

from esdbclient.events import NewEvent, RecordedEvent
from esdbclient.exceptions import (
    DeadlineExceeded,
    ExpectedPositionError,
    GrpcError,
    ServiceUnavailable,
    StreamNotFound,
)
from esdbclient.protos.Grpc.shared_pb2 import UUID, Empty, StreamIdentifier
from esdbclient.protos.Grpc.streams_pb2 import AppendReq, AppendResp, ReadReq, ReadResp
from esdbclient.protos.Grpc.streams_pb2_grpc import StreamsStub


def handle_rpc_error(e: RpcError) -> None:
    if isinstance(e, Call):
        if e.code() == StatusCode.UNAVAILABLE:
            raise ServiceUnavailable(e)
        elif e.code() == StatusCode.DEADLINE_EXCEEDED:
            raise DeadlineExceeded(e)
    raise GrpcError(e) from None


class Streams:
    def __init__(self, channel: Channel):
        self.stub = StreamsStub(channel)

    @overload
    def read(
        self,
        *,
        stream_name: Optional[str] = None,
        stream_position: Optional[int] = None,
        backwards: bool = False,
        limit: int = sys.maxsize,
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        ...  # pragma: no cover

    @overload
    def read(
        self,
        *,
        commit_position: Optional[int] = None,
        backwards: bool = False,
        filter_exclude: Sequence[str] = (),
        filter_include: Sequence[str] = (),
        limit: int = sys.maxsize,
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        ...  # pragma: no cover

    @overload
    def read(
        self,
        *,
        commit_position: Optional[int] = None,
        filter_exclude: Sequence[str] = (),
        filter_include: Sequence[str] = (),
        subscribe: Literal[True],
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        ...  # pragma: no cover

    def read(
        self,
        *,
        stream_name: Optional[str] = None,
        stream_position: Optional[int] = None,
        commit_position: Optional[int] = None,
        backwards: bool = False,
        filter_exclude: Sequence[str] = (),
        filter_include: Sequence[str] = (),
        limit: int = sys.maxsize,
        subscribe: bool = False,
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        """
        Returns iterable of recorded events from the server.

        Either call with `stream_name` and optional `stream_position`
        to read from a given stream, or call without `stream_name`
        and with optional `commit_position` to read from "all streams".

        Calling with `backwards=True` will read events in reverse
        order. Otherwise, events will be read "forwards" in the
        order they were appended (the default is `backwards=False`).

        Reading forwards without specifying a given position will read from
        the start of either the named stream or all streams, and the first
        event will be included. Reading backwards without specifying a given
        position will read from the end of either the named stream or all
        streams, and the last event will be included.

        When reading forwards from either a stream position or a given commit
        position, the event at that position will be included. When reading
        backwards from a given stream position, the event at that position
        will also be included. However, please note, when reading backwards
        from a given commit position, the event at that position will NOT
        be included.

        Calling with `limit` (an integer) will limit the number of
        returned events.

        :param stream_name: Name of the stream.
        :param stream_position: Position in the stream to start reading.
        :param commit_position: Position in the stream to start reading.
        :param backwards: Direction in which to read.
        :param filter_exclude: Sequence of expressions to exclude.
        :param filter_include: Sequence of expressions to include.
        :param limit: Maximum number of events in response.
        :param subscribe: Set True to read future events (default False).
        :param timeout: Optional integer, specifying timeout for operation.
        :return: Iterable of committed events.
        """
        if stream_name is not None:
            assert isinstance(stream_name, str)
            assert commit_position is None
            stream_options = ReadReq.Options.StreamOptions(
                stream_identifier=StreamIdentifier(
                    stream_name=stream_name.encode("utf8")
                ),
                revision=stream_position,
                start=Empty() if stream_position is None and not backwards else None,
                end=Empty() if stream_position is None and backwards else None,
            )
            all_options = None
        else:
            assert stream_position is None
            if isinstance(commit_position, int):
                position = ReadReq.Options.Position(
                    commit_position=commit_position,
                    prepare_position=commit_position,
                )
            else:
                position = None
            stream_options = None
            all_options = ReadReq.Options.AllOptions(
                position=position,
                start=Empty() if position is None and not backwards else None,
                end=Empty() if position is None and backwards else None,
            )

        if backwards is False:
            read_direction = ReadReq.Options.Forwards
        else:
            read_direction = ReadReq.Options.Backwards

        if all_options is not None and (filter_exclude or filter_include):
            if filter_include:
                filter_regex = "^" + "|".join(filter_include) + "$"
            else:
                filter_regex = "^(?!(" + "|".join(filter_exclude) + ")).*$"

            filter_options = ReadReq.Options.FilterOptions(
                stream_identifier=None,
                event_type=ReadReq.Options.FilterOptions.Expression(regex=filter_regex),
                count=Empty(),  # Todo: Figure out what 'window' should be.
            )
        else:
            filter_options = None
        if subscribe:
            subscription_options = ReadReq.Options.SubscriptionOptions()
        else:
            subscription_options = None
        request = ReadReq(
            options=ReadReq.Options(
                stream=stream_options,
                all=all_options,
                read_direction=read_direction,
                resolve_links=False,
                count=limit,
                subscription=subscription_options,
                filter=filter_options,
                no_filter=Empty() if filter_options is None else None,
                uuid_option=ReadReq.Options.UUIDOption(
                    structured=Empty(), string=Empty()
                ),
            )
        )
        try:
            for response in self.stub.Read(request, timeout=timeout):
                assert isinstance(response, ReadResp)
                if response.WhichOneof("content") == "stream_not_found":
                    raise StreamNotFound(f"Stream '{stream_name}' not found")
                yield RecordedEvent(
                    type=response.event.event.metadata["type"],
                    data=response.event.event.data,
                    metadata=response.event.event.custom_metadata,
                    stream_name=response.event.event.stream_identifier.stream_name.decode(
                        "utf8"
                    ),
                    stream_position=response.event.event.stream_revision,
                    commit_position=response.event.commit_position,
                )
        except RpcError as e:
            handle_rpc_error(e)

    def append(
        self,
        stream_name: str,
        expected_position: Optional[int],
        new_events: List[NewEvent],
        timeout: Optional[float] = None,
    ) -> int:
        """
        Appends events to named stream.

        :param stream_name: Name of the stream.
        :param expected_position: Expected stream position. This should be
          `None` for a new stream, otherwise it should be the position of
          the last recorded event in the stream (an non-negative integer).
          If a negative integer is given, optimistic concurrency control
          will be disabled.
        :param new_events: New events to be appended.
        :return: Commit position after events have been appended. This is the
           commit position of the last event to be appended either in this call,
           or in the previous call if zero events were given to be appended.
        """
        if expected_position is None:
            no_stream = Empty()
            any = None
        else:
            assert isinstance(expected_position, int)
            no_stream = None
            if expected_position >= 0:
                any = None
            else:
                expected_position = None
                any = Empty()

        requests = [
            AppendReq(
                options=AppendReq.Options(
                    stream_identifier=StreamIdentifier(
                        stream_name=stream_name.encode("utf8")
                    ),
                    revision=expected_position,
                    no_stream=no_stream,
                    any=any,
                    # stream_exists=None,
                ),
            )
        ]
        for event in new_events:
            requests.append(
                AppendReq(
                    proposed_message=AppendReq.ProposedMessage(
                        id=UUID(string=str(uuid4())),
                        metadata={
                            "type": event.type,
                            "content-type": "application/octet-stream",
                        },
                        custom_metadata=event.metadata,
                        data=event.data,
                    )
                )
            )
        try:
            response = self.stub.Append(iter(requests), timeout=timeout)
        except RpcError as e:
            handle_rpc_error(e)

        assert isinstance(response, AppendResp)
        if response.WhichOneof("result") == "success":
            return response.success.position.commit_position

        if (
            response.wrong_expected_version.WhichOneof("current_revision_option")
            == "current_revision"
        ):
            current_position = response.wrong_expected_version.current_revision
            raise ExpectedPositionError(f"Current position is {current_position}")
        else:
            raise ExpectedPositionError(f"Stream '{stream_name}' does not exist")



# -*- coding: utf-8 -*-
import re
import sys
from typing import Iterable, Iterator, List, Optional, Pattern, Sequence

import grpc

from esdbclient.esdbapi import Streams
from esdbclient.events import NewEvent, RecordedEvent
from esdbclient.exceptions import StreamNotFound


class CatchupSubscription:
    def __init__(
        self,
        event_generator: Iterable[RecordedEvent],
        filter_exclude: Sequence[str] = (),
        filter_include: Sequence[str] = (),
    ):
        self.event_generator = event_generator
        if filter_exclude or filter_include:
            if filter_include:
                filter_regex = "^" + "|".join(filter_include) + "$"
            else:
                filter_regex = "^(?!(" + "|".join(filter_exclude) + ")).*$"
            self.filter_regex: Optional[Pattern[str]] = re.compile(filter_regex)
        else:
            self.filter_regex = None

    def __iter__(self) -> Iterator[RecordedEvent]:
        for event in self.event_generator:
            if event.type == "" and event.stream_name == "":
                # Todo: What is this? occurs several times (has commit_position=0)
                continue
            if self.filter_regex is None:
                yield event
            elif re.match(self.filter_regex, event.type):
                yield event


class EsdbClient:
    def __init__(self, uri: str) -> None:
        self.uri = uri
        self.channel = grpc.insecure_channel(self.uri)
        self.streams = Streams(self.channel)

    def append_events(
        self,
        stream_name: str,
        expected_position: Optional[int],
        events: List[NewEvent],
        timeout: Optional[float] = None,
    ) -> int:
        return self.streams.append(
            stream_name=stream_name,
            expected_position=expected_position,
            new_events=events,
            timeout=timeout,
        )

    def read_stream_events(
        self,
        stream_name: str,
        position: Optional[int] = None,
        backwards: bool = False,
        limit: int = sys.maxsize,
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        return self.streams.read(
            stream_name=stream_name,
            stream_position=position,
            backwards=backwards,
            limit=limit,
            timeout=timeout,
        )

    def read_all_events(
        self,
        position: Optional[int] = None,
        backwards: bool = False,
        filter_exclude: Sequence[str] = ("\\$.*",),  # Exclude "system events".
        filter_include: Sequence[str] = (),
        limit: int = sys.maxsize,
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        return self.streams.read(
            commit_position=position,
            backwards=backwards,
            filter_exclude=filter_exclude,
            filter_include=filter_include,
            limit=limit,
            timeout=timeout,
        )

    def get_stream_position(
        self,
        stream_name: str,
        timeout: Optional[float] = None,
    ) -> Optional[int]:
        try:
            last_event = list(
                self.streams.read(
                    stream_name=stream_name,
                    backwards=True,
                    limit=1,
                    timeout=timeout,
                )
            )[0]
        except StreamNotFound:
            return None
        else:
            return last_event.stream_position

    def get_commit_position(self, timeout: Optional[float] = None) -> int:
        recorded_events = self.read_all_events(
            backwards=True,
            filter_exclude=("\\$.*", ".*Snapshot"),
            limit=1,
            timeout=timeout,
        )
        commit_position = 0
        for ev in recorded_events:
            commit_position = ev.commit_position
        return commit_position

    def subscribe_all_events(
        self,
        position: Optional[int] = None,
        filter_exclude: Sequence[str] = ("\\$.*",),  # Exclude "system events".
        filter_include: Sequence[str] = (),
        timeout: Optional[float] = None,
    ) -> Iterable[RecordedEvent]:
        response = self.streams.read(
            commit_position=position,
            subscribe=True,
            timeout=timeout,
        )
        return CatchupSubscription(
            event_generator=response,
            filter_exclude=filter_exclude,
            filter_include=filter_include,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from esdbclient.protos.Grpc import (
    streams_pb2 as esdbclient_dot_protos_dot_Grpc_dot_streams__pb2,
)


class StreamsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Read = channel.unary_stream(
            "/event_store.client.streams.Streams/Read",
            request_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadReq.SerializeToString,
            response_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadResp.FromString,
        )
        self.Append = channel.stream_unary(
            "/event_store.client.streams.Streams/Append",
            request_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendReq.SerializeToString,
            response_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendResp.FromString,
        )
        self.Delete = channel.unary_unary(
            "/event_store.client.streams.Streams/Delete",
            request_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteReq.SerializeToString,
            response_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteResp.FromString,
        )
        self.Tombstone = channel.unary_unary(
            "/event_store.client.streams.Streams/Tombstone",
            request_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneReq.SerializeToString,
            response_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneResp.FromString,
        )
        self.BatchAppend = channel.stream_stream(
            "/event_store.client.streams.Streams/BatchAppend",
            request_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendReq.SerializeToString,
            response_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendResp.FromString,
        )


class StreamsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Read(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Append(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Tombstone(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchAppend(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StreamsServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Read": grpc.unary_stream_rpc_method_handler(
            servicer.Read,
            request_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadReq.FromString,
            response_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadResp.SerializeToString,
        ),
        "Append": grpc.stream_unary_rpc_method_handler(
            servicer.Append,
            request_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendReq.FromString,
            response_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendResp.SerializeToString,
        ),
        "Delete": grpc.unary_unary_rpc_method_handler(
            servicer.Delete,
            request_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteReq.FromString,
            response_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteResp.SerializeToString,
        ),
        "Tombstone": grpc.unary_unary_rpc_method_handler(
            servicer.Tombstone,
            request_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneReq.FromString,
            response_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneResp.SerializeToString,
        ),
        "BatchAppend": grpc.stream_stream_rpc_method_handler(
            servicer.BatchAppend,
            request_deserializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendReq.FromString,
            response_serializer=esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendResp.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "event_store.client.streams.Streams", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Streams(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Read(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/event_store.client.streams.Streams/Read",
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadReq.SerializeToString,
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.ReadResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Append(
        request_iterator,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            "/event_store.client.streams.Streams/Append",
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendReq.SerializeToString,
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.AppendResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Delete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/event_store.client.streams.Streams/Delete",
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteReq.SerializeToString,
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.DeleteResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Tombstone(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/event_store.client.streams.Streams/Tombstone",
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneReq.SerializeToString,
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.TombstoneResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchAppend(
        request_iterator,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            "/event_store.client.streams.Streams/BatchAppend",
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendReq.SerializeToString,
            esdbclient_dot_protos_dot_Grpc_dot_streams__pb2.BatchAppendResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: esdbclient/protos/Grpc/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import (
    descriptor as _descriptor,
    descriptor_pool as _descriptor_pool,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#esdbclient/protos/Grpc/shared.proto\x12\x12\x65vent_store.client\x1a\x1bgoogle/protobuf/empty.proto"\xa9\x01\n\x04UUID\x12\x39\n\nstructured\x18\x01'
    b" \x01(\x0b\x32#.event_store.client.UUID.StructuredH\x00\x12\x10\n\x06string\x18\x02"
    b" \x01(\tH\x00\x1aK\n\nStructured\x12\x1d\n\x15most_significant_bits\x18\x01"
    b" \x01(\x03\x12\x1e\n\x16least_significant_bits\x18\x02"
    b' \x01(\x03\x42\x07\n\x05value"\x07\n\x05\x45mpty"-\n\x10StreamIdentifier\x12\x13\n\x0bstream_name\x18\x03'
    b' \x01(\x0cJ\x04\x08\x01\x10\x03"F\n\x11\x41llStreamPosition\x12\x17\n\x0f\x63ommit_position\x18\x01'
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b' \x01(\x04"\xf7\x02\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_stream_revision\x18\x01'
    b" \x01(\x04H\x00\x12\x33\n\x11\x63urrent_no_stream\x18\x02"
    b' \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12"\n\x18\x65xpected_stream_position\x18\x03'
    b" \x01(\x04H\x01\x12.\n\x0c\x65xpected_any\x18\x04"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x38\n\x16\x65xpected_stream_exists\x18\x05"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x34\n\x12\x65xpected_no_stream\x18\x06"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42"
    b' \n\x1e\x63urrent_stream_revision_optionB!\n\x1f\x65xpected_stream_position_option"\x0e\n\x0c\x41\x63\x63\x65ssDenied"P\n\rStreamDeleted\x12?\n\x11stream_identifier\x18\x01'
    b' \x01(\x0b\x32$.event_store.client.StreamIdentifier"\t\n\x07Timeout"\t\n\x07Unknown"\x14\n\x12InvalidTransaction"2\n\x19MaximumAppendSizeExceeded\x12\x15\n\rmaxAppendSize\x18\x01'
    b' \x01(\r"\x1d\n\nBadRequest\x12\x0f\n\x07message\x18\x01'
    b" \x01(\tB&\n$com.eventstore.dbclient.proto.sharedb\x06proto3"
)


_UUID = DESCRIPTOR.message_types_by_name["UUID"]
_UUID_STRUCTURED = _UUID.nested_types_by_name["Structured"]
_EMPTY = DESCRIPTOR.message_types_by_name["Empty"]
_STREAMIDENTIFIER = DESCRIPTOR.message_types_by_name["StreamIdentifier"]
_ALLSTREAMPOSITION = DESCRIPTOR.message_types_by_name["AllStreamPosition"]
_WRONGEXPECTEDVERSION = DESCRIPTOR.message_types_by_name["WrongExpectedVersion"]
_ACCESSDENIED = DESCRIPTOR.message_types_by_name["AccessDenied"]
_STREAMDELETED = DESCRIPTOR.message_types_by_name["StreamDeleted"]
_TIMEOUT = DESCRIPTOR.message_types_by_name["Timeout"]
_UNKNOWN = DESCRIPTOR.message_types_by_name["Unknown"]
_INVALIDTRANSACTION = DESCRIPTOR.message_types_by_name["InvalidTransaction"]
_MAXIMUMAPPENDSIZEEXCEEDED = DESCRIPTOR.message_types_by_name[
    "MaximumAppendSizeExceeded"
]
_BADREQUEST = DESCRIPTOR.message_types_by_name["BadRequest"]
UUID = _reflection.GeneratedProtocolMessageType(
    "UUID",
    (_message.Message,),
    {
        "Structured": _reflection.GeneratedProtocolMessageType(
            "Structured",
            (_message.Message,),
            {
                "DESCRIPTOR": _UUID_STRUCTURED,
                "__module__": "esdbclient.protos.Grpc.shared_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.UUID.Structured)
            },
        ),
        "DESCRIPTOR": _UUID,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.UUID)
    },
)
_sym_db.RegisterMessage(UUID)
_sym_db.RegisterMessage(UUID.Structured)

Empty = _reflection.GeneratedProtocolMessageType(
    "Empty",
    (_message.Message,),
    {
        "DESCRIPTOR": _EMPTY,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Empty)
    },
)
_sym_db.RegisterMessage(Empty)

StreamIdentifier = _reflection.GeneratedProtocolMessageType(
    "StreamIdentifier",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMIDENTIFIER,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.StreamIdentifier)
    },
)
_sym_db.RegisterMessage(StreamIdentifier)

AllStreamPosition = _reflection.GeneratedProtocolMessageType(
    "AllStreamPosition",
    (_message.Message,),
    {
        "DESCRIPTOR": _ALLSTREAMPOSITION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.AllStreamPosition)
    },
)
_sym_db.RegisterMessage(AllStreamPosition)

WrongExpectedVersion = _reflection.GeneratedProtocolMessageType(
    "WrongExpectedVersion",
    (_message.Message,),
    {
        "DESCRIPTOR": _WRONGEXPECTEDVERSION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.WrongExpectedVersion)
    },
)
_sym_db.RegisterMessage(WrongExpectedVersion)

AccessDenied = _reflection.GeneratedProtocolMessageType(
    "AccessDenied",
    (_message.Message,),
    {
        "DESCRIPTOR": _ACCESSDENIED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.AccessDenied)
    },
)
_sym_db.RegisterMessage(AccessDenied)

StreamDeleted = _reflection.GeneratedProtocolMessageType(
    "StreamDeleted",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMDELETED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.StreamDeleted)
    },
)
_sym_db.RegisterMessage(StreamDeleted)

Timeout = _reflection.GeneratedProtocolMessageType(
    "Timeout",
    (_message.Message,),
    {
        "DESCRIPTOR": _TIMEOUT,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Timeout)
    },
)
_sym_db.RegisterMessage(Timeout)

Unknown = _reflection.GeneratedProtocolMessageType(
    "Unknown",
    (_message.Message,),
    {
        "DESCRIPTOR": _UNKNOWN,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Unknown)
    },
)
_sym_db.RegisterMessage(Unknown)

InvalidTransaction = _reflection.GeneratedProtocolMessageType(
    "InvalidTransaction",
    (_message.Message,),
    {
        "DESCRIPTOR": _INVALIDTRANSACTION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.InvalidTransaction)
    },
)
_sym_db.RegisterMessage(InvalidTransaction)

MaximumAppendSizeExceeded = _reflection.GeneratedProtocolMessageType(
    "MaximumAppendSizeExceeded",
    (_message.Message,),
    {
        "DESCRIPTOR": _MAXIMUMAPPENDSIZEEXCEEDED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.MaximumAppendSizeExceeded)
    },
)
_sym_db.RegisterMessage(MaximumAppendSizeExceeded)

BadRequest = _reflection.GeneratedProtocolMessageType(
    "BadRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BADREQUEST,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.BadRequest)
    },
)
_sym_db.RegisterMessage(BadRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n$com.eventstore.dbclient.proto.shared"
    _UUID._serialized_start = 89
    _UUID._serialized_end = 258
    _UUID_STRUCTURED._serialized_start = 174
    _UUID_STRUCTURED._serialized_end = 249
    _EMPTY._serialized_start = 260
    _EMPTY._serialized_end = 267
    _STREAMIDENTIFIER._serialized_start = 269
    _STREAMIDENTIFIER._serialized_end = 314
    _ALLSTREAMPOSITION._serialized_start = 316
    _ALLSTREAMPOSITION._serialized_end = 386
    _WRONGEXPECTEDVERSION._serialized_start = 389
    _WRONGEXPECTEDVERSION._serialized_end = 764
    _ACCESSDENIED._serialized_start = 766
    _ACCESSDENIED._serialized_end = 780
    _STREAMDELETED._serialized_start = 782
    _STREAMDELETED._serialized_end = 862
    _TIMEOUT._serialized_start = 864
    _TIMEOUT._serialized_end = 873
    _UNKNOWN._serialized_start = 875
    _UNKNOWN._serialized_end = 884
    _INVALIDTRANSACTION._serialized_start = 886
    _INVALIDTRANSACTION._serialized_end = 906
    _MAXIMUMAPPENDSIZEEXCEEDED._serialized_start = 908
    _MAXIMUMAPPENDSIZEEXCEEDED._serialized_end = 958
    _BADREQUEST._serialized_start = 960
    _BADREQUEST._serialized_end = 989
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UUID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Structured(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        MOST_SIGNIFICANT_BITS_FIELD_NUMBER: builtins.int
        LEAST_SIGNIFICANT_BITS_FIELD_NUMBER: builtins.int
        most_significant_bits: builtins.int
        least_significant_bits: builtins.int
        def __init__(
            self,
            *,
            most_significant_bits: builtins.int = ...,
            least_significant_bits: builtins.int = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "least_significant_bits",
                b"least_significant_bits",
                "most_significant_bits",
                b"most_significant_bits",
            ],
        ) -> None: ...

    STRUCTURED_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    @property
    def structured(self) -> global___UUID.Structured: ...
    string: typing.Text
    def __init__(
        self,
        *,
        structured: typing.Optional[global___UUID.Structured] = ...,
        string: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "string", b"string", "structured", b"structured", "value", b"value"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "string", b"string", "structured", b"structured", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["value", b"value"]
    ) -> typing.Optional[typing_extensions.Literal["structured", "string"]]: ...

global___UUID = UUID

class Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

class StreamIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STREAM_NAME_FIELD_NUMBER: builtins.int
    stream_name: builtins.bytes
    def __init__(
        self,
        *,
        stream_name: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["stream_name", b"stream_name"]
    ) -> None: ...

global___StreamIdentifier = StreamIdentifier

class AllStreamPosition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMIT_POSITION_FIELD_NUMBER: builtins.int
    PREPARE_POSITION_FIELD_NUMBER: builtins.int
    commit_position: builtins.int
    prepare_position: builtins.int
    def __init__(
        self,
        *,
        commit_position: builtins.int = ...,
        prepare_position: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "commit_position",
            b"commit_position",
            "prepare_position",
            b"prepare_position",
        ],
    ) -> None: ...

global___AllStreamPosition = AllStreamPosition

class WrongExpectedVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURRENT_STREAM_REVISION_FIELD_NUMBER: builtins.int
    CURRENT_NO_STREAM_FIELD_NUMBER: builtins.int
    EXPECTED_STREAM_POSITION_FIELD_NUMBER: builtins.int
    EXPECTED_ANY_FIELD_NUMBER: builtins.int
    EXPECTED_STREAM_EXISTS_FIELD_NUMBER: builtins.int
    EXPECTED_NO_STREAM_FIELD_NUMBER: builtins.int
    current_stream_revision: builtins.int
    @property
    def current_no_stream(self) -> google.protobuf.empty_pb2.Empty: ...
    expected_stream_position: builtins.int
    @property
    def expected_any(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def expected_stream_exists(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def expected_no_stream(self) -> google.protobuf.empty_pb2.Empty: ...
    def __init__(
        self,
        *,
        current_stream_revision: builtins.int = ...,
        current_no_stream: typing.Optional[google.protobuf.empty_pb2.Empty] = ...,
        expected_stream_position: builtins.int = ...,
        expected_any: typing.Optional[google.protobuf.empty_pb2.Empty] = ...,
        expected_stream_exists: typing.Optional[google.protobuf.empty_pb2.Empty] = ...,
        expected_no_stream: typing.Optional[google.protobuf.empty_pb2.Empty] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "current_no_stream",
            b"current_no_stream",
            "current_stream_revision",
            b"current_stream_revision",
            "current_stream_revision_option",
            b"current_stream_revision_option",
            "expected_any",
            b"expected_any",
            "expected_no_stream",
            b"expected_no_stream",
            "expected_stream_exists",
            b"expected_stream_exists",
            "expected_stream_position",
            b"expected_stream_position",
            "expected_stream_position_option",
            b"expected_stream_position_option",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "current_no_stream",
            b"current_no_stream",
            "current_stream_revision",
            b"current_stream_revision",
            "current_stream_revision_option",
            b"current_stream_revision_option",
            "expected_any",
            b"expected_any",
            "expected_no_stream",
            b"expected_no_stream",
            "expected_stream_exists",
            b"expected_stream_exists",
            "expected_stream_position",
            b"expected_stream_position",
            "expected_stream_position_option",
            b"expected_stream_position_option",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "current_stream_revision_option", b"current_stream_revision_option"
        ],
    ) -> typing.Optional[
        typing_extensions.Literal["current_stream_revision", "current_no_stream"]
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "expected_stream_position_option", b"expected_stream_position_option"
        ],
    ) -> typing.Optional[
        typing_extensions.Literal[
            "expected_stream_position",
            "expected_any",
            "expected_stream_exists",
            "expected_no_stream",
        ]
    ]: ...

global___WrongExpectedVersion = WrongExpectedVersion

class AccessDenied(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(
        self,
    ) -> None: ...

global___AccessDenied = AccessDenied

class StreamDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def stream_identifier(self) -> global___StreamIdentifier: ...
    def __init__(
        self,
        *,
        stream_identifier: typing.Optional[global___StreamIdentifier] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "stream_identifier", b"stream_identifier"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "stream_identifier", b"stream_identifier"
        ],
    ) -> None: ...

global___StreamDeleted = StreamDeleted

class Timeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(
        self,
    ) -> None: ...

global___Timeout = Timeout

class Unknown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(
        self,
    ) -> None: ...

global___Unknown = Unknown

class InvalidTransaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(
        self,
    ) -> None: ...

global___InvalidTransaction = InvalidTransaction

class MaximumAppendSizeExceeded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MAXAPPENDSIZE_FIELD_NUMBER: builtins.int
    maxAppendSize: builtins.int
    def __init__(
        self,
        *,
        maxAppendSize: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["maxAppendSize", b"maxAppendSize"]
    ) -> None: ...

global___MaximumAppendSizeExceeded = MaximumAppendSizeExceeded

class BadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_FIELD_NUMBER: builtins.int
    message: typing.Text
    def __init__(
        self,
        *,
        message: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["message", b"message"]
    ) -> None: ...

global___BadRequest = BadRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: esdbclient/protos/Grpc/streams.proto
"""Generated protocol buffer code."""
from google.protobuf import (
    descriptor as _descriptor,
    descriptor_pool as _descriptor_pool,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import (
    duration_pb2 as google_dot_protobuf_dot_duration__pb2,
    empty_pb2 as google_dot_protobuf_dot_empty__pb2,
    timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2,
)

from esdbclient.protos.Grpc import (
    shared_pb2 as esdbclient_dot_protos_dot_Grpc_dot_shared__pb2,
    status_pb2 as esdbclient_dot_protos_dot_Grpc_dot_status__pb2,
)

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$esdbclient/protos/Grpc/streams.proto\x12\x1a\x65vent_store.client.streams\x1a#esdbclient/protos/Grpc/shared.proto\x1a#esdbclient/protos/Grpc/status.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xad\x0e\n\x07ReadReq\x12<\n\x07options\x18\x01'
    b" \x01(\x0b\x32+.event_store.client.streams.ReadReq.Options\x1a\xe3\r\n\x07Options\x12K\n\x06stream\x18\x01"
    b" \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.StreamOptionsH\x00\x12\x45\n\x03\x61ll\x18\x02"
    b" \x01(\x0b\x32\x36.event_store.client.streams.ReadReq.Options.AllOptionsH\x00\x12Q\n\x0eread_direction\x18\x03"
    b" \x01(\x0e\x32\x39.event_store.client.streams.ReadReq.Options.ReadDirection\x12\x15\n\rresolve_links\x18\x04"
    b" \x01(\x08\x12\x0f\n\x05\x63ount\x18\x05"
    b" \x01(\x04H\x01\x12W\n\x0csubscription\x18\x06"
    b" \x01(\x0b\x32?.event_store.client.streams.ReadReq.Options.SubscriptionOptionsH\x01\x12K\n\x06\x66ilter\x18\x07"
    b" \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.FilterOptionsH\x02\x12.\n\tno_filter\x18\x08"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x02\x12K\n\x0buuid_option\x18\t"
    b" \x01(\x0b\x32\x36.event_store.client.streams.ReadReq.Options.UUIDOption\x12Q\n\x0e\x63ontrol_option\x18\n"
    b" \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.ControlOption\x1a\xcd\x01\n\rStreamOptions\x12?\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02"
    b" \x01(\x04H\x00\x12*\n\x05start\x18\x03"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x11\n\x0frevision_option\x1a\xba\x01\n\nAllOptions\x12H\n\x08position\x18\x01"
    b" \x01(\x0b\x32\x34.event_store.client.streams.ReadReq.Options.PositionH\x00\x12*\n\x05start\x18\x02"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x03"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x0c\n\nall_option\x1a\x15\n\x13SubscriptionOptions\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b" \x01(\x04\x1a\xf0\x02\n\rFilterOptions\x12\x61\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32\x44.event_store.client.streams.ReadReq.Options.FilterOptions.ExpressionH\x00\x12Z\n\nevent_type\x18\x02"
    b" \x01(\x0b\x32\x44.event_store.client.streams.ReadReq.Options.FilterOptions.ExpressionH\x00\x12\r\n\x03max\x18\x03"
    b" \x01(\rH\x01\x12*\n\x05\x63ount\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12$\n\x1c\x63heckpointIntervalMultiplier\x18\x05"
    b" \x01(\r\x1a+\n\nExpression\x12\r\n\x05regex\x18\x01"
    b" \x01(\t\x12\x0e\n\x06prefix\x18\x02"
    b" \x03(\tB\x08\n\x06\x66ilterB\x08\n\x06window\x1au\n\nUUIDOption\x12/\n\nstructured\x18\x01"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12+\n\x06string\x18\x02"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\t\n\x07\x63ontent\x1a&\n\rControlOption\x12\x15\n\rcompatibility\x18\x01"
    b' \x01(\r",\n\rReadDirection\x12\x0c\n\x08\x46orwards\x10\x00\x12\r\n\tBackwards\x10\x01\x42\x0f\n\rstream_optionB\x0e\n\x0c\x63ount_optionB\x0f\n\rfilter_option"\x95\n\n\x08ReadResp\x12?\n\x05\x65vent\x18\x01'
    b" \x01(\x0b\x32..event_store.client.streams.ReadResp.ReadEventH\x00\x12U\n\x0c\x63onfirmation\x18\x02"
    b" \x01(\x0b\x32=.event_store.client.streams.ReadResp.SubscriptionConfirmationH\x00\x12\x45\n\ncheckpoint\x18\x03"
    b" \x01(\x0b\x32/.event_store.client.streams.ReadResp.CheckpointH\x00\x12O\n\x10stream_not_found\x18\x04"
    b" \x01(\x0b\x32\x33.event_store.client.streams.ReadResp.StreamNotFoundH\x00\x12\x1f\n\x15\x66irst_stream_position\x18\x05"
    b" \x01(\x04H\x00\x12\x1e\n\x14last_stream_position\x18\x06"
    b" \x01(\x04H\x00\x12I\n\x18last_all_stream_position\x18\x07"
    b" \x01(\x0b\x32%.event_store.client.AllStreamPositionH\x00\x1a\xf8\x04\n\tReadEvent\x12K\n\x05\x65vent\x18\x01"
    b" \x01(\x0b\x32<.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent\x12J\n\x04link\x18\x02"
    b" \x01(\x0b\x32<.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent\x12\x19\n\x0f\x63ommit_position\x18\x03"
    b" \x01(\x04H\x00\x12\x30\n\x0bno_position\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a\xf8\x02\n\rRecordedEvent\x12$\n\x02id\x18\x01"
    b" \x01(\x0b\x32\x18.event_store.client.UUID\x12?\n\x11stream_identifier\x18\x02"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x17\n\x0fstream_revision\x18\x03"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x04"
    b" \x01(\x04\x12\x17\n\x0f\x63ommit_position\x18\x05"
    b" \x01(\x04\x12\\\n\x08metadata\x18\x06"
    b" \x03(\x0b\x32J.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x07"
    b" \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x08"
    b" \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01"
    b" \x01(\t\x12\r\n\x05value\x18\x02"
    b" \x01(\t:\x02\x38\x01\x42\n\n\x08position\x1a\x33\n\x18SubscriptionConfirmation\x12\x17\n\x0fsubscription_id\x18\x01"
    b" \x01(\t\x1a?\n\nCheckpoint\x12\x17\n\x0f\x63ommit_position\x18\x01"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b" \x01(\x04\x1aQ\n\x0eStreamNotFound\x12?\n\x11stream_identifier\x18\x01"
    b' \x01(\x0b\x32$.event_store.client.StreamIdentifierB\t\n\x07\x63ontent"\x9f\x05\n\tAppendReq\x12@\n\x07options\x18\x01'
    b" \x01(\x0b\x32-.event_store.client.streams.AppendReq.OptionsH\x00\x12Q\n\x10proposed_message\x18\x02"
    b" \x01(\x0b\x32\x35.event_store.client.streams.AppendReq.ProposedMessageH\x00\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02"
    b" \x01(\x04H\x00\x12.\n\tno_stream\x18\x03"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision\x1a\xe6\x01\n\x0fProposedMessage\x12$\n\x02id\x18\x01"
    b" \x01(\x0b\x32\x18.event_store.client.UUID\x12U\n\x08metadata\x18\x02"
    b" \x03(\x0b\x32\x43.event_store.client.streams.AppendReq.ProposedMessage.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x03"
    b" \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04"
    b" \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01"
    b" \x01(\t\x12\r\n\x05value\x18\x02"
    b' \x01(\t:\x02\x38\x01\x42\t\n\x07\x63ontent"\x8d\t\n\nAppendResp\x12\x41\n\x07success\x18\x01'
    b" \x01(\x0b\x32..event_store.client.streams.AppendResp.SuccessH\x00\x12]\n\x16wrong_expected_version\x18\x02"
    b" \x01(\x0b\x32;.event_store.client.streams.AppendResp.WrongExpectedVersionH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b" \x01(\x04\x1a\xfa\x01\n\x07Success\x12\x1a\n\x10\x63urrent_revision\x18\x01"
    b" \x01(\x04H\x00\x12.\n\tno_stream\x18\x02"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x43\n\x08position\x18\x03"
    b" \x01(\x0b\x32/.event_store.client.streams.AppendResp.PositionH\x01\x12\x30\n\x0bno_position\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x42\x19\n\x17\x63urrent_revision_optionB\x11\n\x0fposition_option\x1a\x96\x05\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_revision_20_6_0\x18\x01"
    b" \x01(\x04H\x00\x12\x35\n\x10no_stream_20_6_0\x18\x02"
    b' \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12"\n\x18\x65xpected_revision_20_6_0\x18\x03'
    b" \x01(\x04H\x01\x12/\n\nany_20_6_0\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12\x39\n\x14stream_exists_20_6_0\x18\x05"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12\x1a\n\x10\x63urrent_revision\x18\x06"
    b" \x01(\x04H\x02\x12\x36\n\x11\x63urrent_no_stream\x18\x07"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x02\x12\x1b\n\x11\x65xpected_revision\x18\x08"
    b" \x01(\x04H\x03\x12\x31\n\x0c\x65xpected_any\x18\t"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x12;\n\x16\x65xpected_stream_exists\x18\n"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x12\x37\n\x12\x65xpected_no_stream\x18\x0b"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x42"
    b' \n\x1e\x63urrent_revision_option_20_6_0B!\n\x1f\x65xpected_revision_option_20_6_0B\x19\n\x17\x63urrent_revision_optionB\x1a\n\x18\x65xpected_revision_optionB\x08\n\x06result"\xe1\x06\n\x0e\x42\x61tchAppendReq\x12\x30\n\x0e\x63orrelation_id\x18\x01'
    b" \x01(\x0b\x32\x18.event_store.client.UUID\x12\x43\n\x07options\x18\x02"
    b" \x01(\x0b\x32\x32.event_store.client.streams.BatchAppendReq.Options\x12U\n\x11proposed_messages\x18\x03"
    b" \x03(\x0b\x32:.event_store.client.streams.BatchAppendReq.ProposedMessage\x12\x10\n\x08is_final\x18\x04"
    b" \x01(\x08\x1a\x80\x03\n\x07Options\x12?\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x19\n\x0fstream_position\x18\x02"
    b" \x01(\x04H\x00\x12+\n\tno_stream\x18\x03"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12%\n\x03\x61ny\x18\x04"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rstream_exists\x18\x05"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x36\n\x10\x64\x65\x61\x64line_21_10_0\x18\x06"
    b" \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12-\n\x08\x64\x65\x61\x64line\x18\x07"
    b" \x01(\x0b\x32\x19.google.protobuf.DurationH\x01\x42\x1a\n\x18\x65xpected_stream_positionB\x11\n\x0f\x64\x65\x61\x64line_option\x1a\xeb\x01\n\x0fProposedMessage\x12$\n\x02id\x18\x01"
    b" \x01(\x0b\x32\x18.event_store.client.UUID\x12Z\n\x08metadata\x18\x02"
    b" \x03(\x0b\x32H.event_store.client.streams.BatchAppendReq.ProposedMessage.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x03"
    b" \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04"
    b" \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01"
    b" \x01(\t\x12\r\n\x05value\x18\x02"
    b' \x01(\t:\x02\x38\x01"\xa4\x05\n\x0f\x42\x61tchAppendResp\x12\x30\n\x0e\x63orrelation_id\x18\x01'
    b" \x01(\x0b\x32\x18.event_store.client.UUID\x12#\n\x05\x65rror\x18\x02"
    b" \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12\x46\n\x07success\x18\x03"
    b" \x01(\x0b\x32\x33.event_store.client.streams.BatchAppendResp.SuccessH\x00\x12?\n\x11stream_identifier\x18\x04"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x19\n\x0fstream_position\x18\x05"
    b" \x01(\x04H\x01\x12+\n\tno_stream\x18\x06"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12%\n\x03\x61ny\x18\x07"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12/\n\rstream_exists\x18\x08"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x1a\xea\x01\n\x07Success\x12\x1a\n\x10\x63urrent_revision\x18\x01"
    b" \x01(\x04H\x00\x12+\n\tno_stream\x18\x02"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x39\n\x08position\x18\x03"
    b" \x01(\x0b\x32%.event_store.client.AllStreamPositionH\x01\x12-\n\x0bno_position\x18\x04"
    b' \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42\x19\n\x17\x63urrent_revision_optionB\x11\n\x0fposition_optionB\x08\n\x06resultB\x1a\n\x18\x65xpected_stream_position"\xd6\x02\n\tDeleteReq\x12>\n\x07options\x18\x01'
    b" \x01(\x0b\x32-.event_store.client.streams.DeleteReq.Options\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02"
    b" \x01(\x04H\x00\x12.\n\tno_stream\x18\x03"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05"
    b' \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision"\xd5\x01\n\nDeleteResp\x12\x43\n\x08position\x18\x01'
    b" \x01(\x0b\x32/.event_store.client.streams.DeleteResp.PositionH\x00\x12\x30\n\x0bno_position\x18\x02"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b' \x01(\x04\x42\x11\n\x0fposition_option"\xdc\x02\n\x0cTombstoneReq\x12\x41\n\x07options\x18\x01'
    b" \x01(\x0b\x32\x30.event_store.client.streams.TombstoneReq.Options\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01"
    b" \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02"
    b" \x01(\x04H\x00\x12.\n\tno_stream\x18\x03"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05"
    b' \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision"\xdb\x01\n\rTombstoneResp\x12\x46\n\x08position\x18\x01'
    b" \x01(\x0b\x32\x32.event_store.client.streams.TombstoneResp.PositionH\x00\x12\x30\n\x0bno_position\x18\x02"
    b" \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01"
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b" \x01(\x04\x42\x11\n\x0fposition_option2\xe0\x03\n\x07Streams\x12S\n\x04Read\x12#.event_store.client.streams.ReadReq\x1a$.event_store.client.streams.ReadResp0\x01\x12Y\n\x06\x41ppend\x12%.event_store.client.streams.AppendReq\x1a&.event_store.client.streams.AppendResp(\x01\x12W\n\x06\x44\x65lete\x12%.event_store.client.streams.DeleteReq\x1a&.event_store.client.streams.DeleteResp\x12`\n\tTombstone\x12(.event_store.client.streams.TombstoneReq\x1a).event_store.client.streams.TombstoneResp\x12j\n\x0b\x42\x61tchAppend\x12*.event_store.client.streams.BatchAppendReq\x1a+.event_store.client.streams.BatchAppendResp(\x01\x30\x01\x42'\n%com.eventstore.dbclient.proto.streamsb\x06proto3"
)


_READREQ = DESCRIPTOR.message_types_by_name["ReadReq"]
_READREQ_OPTIONS = _READREQ.nested_types_by_name["Options"]
_READREQ_OPTIONS_STREAMOPTIONS = _READREQ_OPTIONS.nested_types_by_name["StreamOptions"]
_READREQ_OPTIONS_ALLOPTIONS = _READREQ_OPTIONS.nested_types_by_name["AllOptions"]
_READREQ_OPTIONS_SUBSCRIPTIONOPTIONS = _READREQ_OPTIONS.nested_types_by_name[
    "SubscriptionOptions"
]
_READREQ_OPTIONS_POSITION = _READREQ_OPTIONS.nested_types_by_name["Position"]
_READREQ_OPTIONS_FILTEROPTIONS = _READREQ_OPTIONS.nested_types_by_name["FilterOptions"]
_READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION = (
    _READREQ_OPTIONS_FILTEROPTIONS.nested_types_by_name["Expression"]
)
_READREQ_OPTIONS_UUIDOPTION = _READREQ_OPTIONS.nested_types_by_name["UUIDOption"]
_READREQ_OPTIONS_CONTROLOPTION = _READREQ_OPTIONS.nested_types_by_name["ControlOption"]
_READRESP = DESCRIPTOR.message_types_by_name["ReadResp"]
_READRESP_READEVENT = _READRESP.nested_types_by_name["ReadEvent"]
_READRESP_READEVENT_RECORDEDEVENT = _READRESP_READEVENT.nested_types_by_name[
    "RecordedEvent"
]
_READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY = (
    _READRESP_READEVENT_RECORDEDEVENT.nested_types_by_name["MetadataEntry"]
)
_READRESP_SUBSCRIPTIONCONFIRMATION = _READRESP.nested_types_by_name[
    "SubscriptionConfirmation"
]
_READRESP_CHECKPOINT = _READRESP.nested_types_by_name["Checkpoint"]
_READRESP_STREAMNOTFOUND = _READRESP.nested_types_by_name["StreamNotFound"]
_APPENDREQ = DESCRIPTOR.message_types_by_name["AppendReq"]
_APPENDREQ_OPTIONS = _APPENDREQ.nested_types_by_name["Options"]
_APPENDREQ_PROPOSEDMESSAGE = _APPENDREQ.nested_types_by_name["ProposedMessage"]
_APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY = (
    _APPENDREQ_PROPOSEDMESSAGE.nested_types_by_name["MetadataEntry"]
)
_APPENDRESP = DESCRIPTOR.message_types_by_name["AppendResp"]
_APPENDRESP_POSITION = _APPENDRESP.nested_types_by_name["Position"]
_APPENDRESP_SUCCESS = _APPENDRESP.nested_types_by_name["Success"]
_APPENDRESP_WRONGEXPECTEDVERSION = _APPENDRESP.nested_types_by_name[
    "WrongExpectedVersion"
]
_BATCHAPPENDREQ = DESCRIPTOR.message_types_by_name["BatchAppendReq"]
_BATCHAPPENDREQ_OPTIONS = _BATCHAPPENDREQ.nested_types_by_name["Options"]
_BATCHAPPENDREQ_PROPOSEDMESSAGE = _BATCHAPPENDREQ.nested_types_by_name[
    "ProposedMessage"
]
_BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY = (
    _BATCHAPPENDREQ_PROPOSEDMESSAGE.nested_types_by_name["MetadataEntry"]
)
_BATCHAPPENDRESP = DESCRIPTOR.message_types_by_name["BatchAppendResp"]
_BATCHAPPENDRESP_SUCCESS = _BATCHAPPENDRESP.nested_types_by_name["Success"]
_DELETEREQ = DESCRIPTOR.message_types_by_name["DeleteReq"]
_DELETEREQ_OPTIONS = _DELETEREQ.nested_types_by_name["Options"]
_DELETERESP = DESCRIPTOR.message_types_by_name["DeleteResp"]
_DELETERESP_POSITION = _DELETERESP.nested_types_by_name["Position"]
_TOMBSTONEREQ = DESCRIPTOR.message_types_by_name["TombstoneReq"]
_TOMBSTONEREQ_OPTIONS = _TOMBSTONEREQ.nested_types_by_name["Options"]
_TOMBSTONERESP = DESCRIPTOR.message_types_by_name["TombstoneResp"]
_TOMBSTONERESP_POSITION = _TOMBSTONERESP.nested_types_by_name["Position"]
_READREQ_OPTIONS_READDIRECTION = _READREQ_OPTIONS.enum_types_by_name["ReadDirection"]
ReadReq = _reflection.GeneratedProtocolMessageType(
    "ReadReq",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "StreamOptions": _reflection.GeneratedProtocolMessageType(
                    "StreamOptions",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_STREAMOPTIONS,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.StreamOptions)
                    },
                ),
                "AllOptions": _reflection.GeneratedProtocolMessageType(
                    "AllOptions",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_ALLOPTIONS,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.AllOptions)
                    },
                ),
                "SubscriptionOptions": _reflection.GeneratedProtocolMessageType(
                    "SubscriptionOptions",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_SUBSCRIPTIONOPTIONS,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.SubscriptionOptions)
                    },
                ),
                "Position": _reflection.GeneratedProtocolMessageType(
                    "Position",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_POSITION,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.Position)
                    },
                ),
                "FilterOptions": _reflection.GeneratedProtocolMessageType(
                    "FilterOptions",
                    (_message.Message,),
                    {
                        "Expression": _reflection.GeneratedProtocolMessageType(
                            "Expression",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION,
                                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.FilterOptions.Expression)
                            },
                        ),
                        "DESCRIPTOR": _READREQ_OPTIONS_FILTEROPTIONS,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.FilterOptions)
                    },
                ),
                "UUIDOption": _reflection.GeneratedProtocolMessageType(
                    "UUIDOption",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_UUIDOPTION,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.UUIDOption)
                    },
                ),
                "ControlOption": _reflection.GeneratedProtocolMessageType(
                    "ControlOption",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _READREQ_OPTIONS_CONTROLOPTION,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options.ControlOption)
                    },
                ),
                "DESCRIPTOR": _READREQ_OPTIONS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq.Options)
            },
        ),
        "DESCRIPTOR": _READREQ,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadReq)
    },
)
_sym_db.RegisterMessage(ReadReq)
_sym_db.RegisterMessage(ReadReq.Options)
_sym_db.RegisterMessage(ReadReq.Options.StreamOptions)
_sym_db.RegisterMessage(ReadReq.Options.AllOptions)
_sym_db.RegisterMessage(ReadReq.Options.SubscriptionOptions)
_sym_db.RegisterMessage(ReadReq.Options.Position)
_sym_db.RegisterMessage(ReadReq.Options.FilterOptions)
_sym_db.RegisterMessage(ReadReq.Options.FilterOptions.Expression)
_sym_db.RegisterMessage(ReadReq.Options.UUIDOption)
_sym_db.RegisterMessage(ReadReq.Options.ControlOption)

ReadResp = _reflection.GeneratedProtocolMessageType(
    "ReadResp",
    (_message.Message,),
    {
        "ReadEvent": _reflection.GeneratedProtocolMessageType(
            "ReadEvent",
            (_message.Message,),
            {
                "RecordedEvent": _reflection.GeneratedProtocolMessageType(
                    "RecordedEvent",
                    (_message.Message,),
                    {
                        "MetadataEntry": _reflection.GeneratedProtocolMessageType(
                            "MetadataEntry",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY,
                                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.ReadEvent.RecordedEvent.MetadataEntry)
                            },
                        ),
                        "DESCRIPTOR": _READRESP_READEVENT_RECORDEDEVENT,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.ReadEvent.RecordedEvent)
                    },
                ),
                "DESCRIPTOR": _READRESP_READEVENT,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.ReadEvent)
            },
        ),
        "SubscriptionConfirmation": _reflection.GeneratedProtocolMessageType(
            "SubscriptionConfirmation",
            (_message.Message,),
            {
                "DESCRIPTOR": _READRESP_SUBSCRIPTIONCONFIRMATION,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.SubscriptionConfirmation)
            },
        ),
        "Checkpoint": _reflection.GeneratedProtocolMessageType(
            "Checkpoint",
            (_message.Message,),
            {
                "DESCRIPTOR": _READRESP_CHECKPOINT,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.Checkpoint)
            },
        ),
        "StreamNotFound": _reflection.GeneratedProtocolMessageType(
            "StreamNotFound",
            (_message.Message,),
            {
                "DESCRIPTOR": _READRESP_STREAMNOTFOUND,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp.StreamNotFound)
            },
        ),
        "DESCRIPTOR": _READRESP,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.ReadResp)
    },
)
_sym_db.RegisterMessage(ReadResp)
_sym_db.RegisterMessage(ReadResp.ReadEvent)
_sym_db.RegisterMessage(ReadResp.ReadEvent.RecordedEvent)
_sym_db.RegisterMessage(ReadResp.ReadEvent.RecordedEvent.MetadataEntry)
_sym_db.RegisterMessage(ReadResp.SubscriptionConfirmation)
_sym_db.RegisterMessage(ReadResp.Checkpoint)
_sym_db.RegisterMessage(ReadResp.StreamNotFound)

AppendReq = _reflection.GeneratedProtocolMessageType(
    "AppendReq",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPENDREQ_OPTIONS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendReq.Options)
            },
        ),
        "ProposedMessage": _reflection.GeneratedProtocolMessageType(
            "ProposedMessage",
            (_message.Message,),
            {
                "MetadataEntry": _reflection.GeneratedProtocolMessageType(
                    "MetadataEntry",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendReq.ProposedMessage.MetadataEntry)
                    },
                ),
                "DESCRIPTOR": _APPENDREQ_PROPOSEDMESSAGE,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendReq.ProposedMessage)
            },
        ),
        "DESCRIPTOR": _APPENDREQ,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendReq)
    },
)
_sym_db.RegisterMessage(AppendReq)
_sym_db.RegisterMessage(AppendReq.Options)
_sym_db.RegisterMessage(AppendReq.ProposedMessage)
_sym_db.RegisterMessage(AppendReq.ProposedMessage.MetadataEntry)

AppendResp = _reflection.GeneratedProtocolMessageType(
    "AppendResp",
    (_message.Message,),
    {
        "Position": _reflection.GeneratedProtocolMessageType(
            "Position",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPENDRESP_POSITION,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendResp.Position)
            },
        ),
        "Success": _reflection.GeneratedProtocolMessageType(
            "Success",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPENDRESP_SUCCESS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendResp.Success)
            },
        ),
        "WrongExpectedVersion": _reflection.GeneratedProtocolMessageType(
            "WrongExpectedVersion",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPENDRESP_WRONGEXPECTEDVERSION,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendResp.WrongExpectedVersion)
            },
        ),
        "DESCRIPTOR": _APPENDRESP,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.AppendResp)
    },
)
_sym_db.RegisterMessage(AppendResp)
_sym_db.RegisterMessage(AppendResp.Position)
_sym_db.RegisterMessage(AppendResp.Success)
_sym_db.RegisterMessage(AppendResp.WrongExpectedVersion)

BatchAppendReq = _reflection.GeneratedProtocolMessageType(
    "BatchAppendReq",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _BATCHAPPENDREQ_OPTIONS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendReq.Options)
            },
        ),
        "ProposedMessage": _reflection.GeneratedProtocolMessageType(
            "ProposedMessage",
            (_message.Message,),
            {
                "MetadataEntry": _reflection.GeneratedProtocolMessageType(
                    "MetadataEntry",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY,
                        "__module__": "esdbclient.protos.Grpc.streams_pb2"
                        # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendReq.ProposedMessage.MetadataEntry)
                    },
                ),
                "DESCRIPTOR": _BATCHAPPENDREQ_PROPOSEDMESSAGE,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendReq.ProposedMessage)
            },
        ),
        "DESCRIPTOR": _BATCHAPPENDREQ,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendReq)
    },
)
_sym_db.RegisterMessage(BatchAppendReq)
_sym_db.RegisterMessage(BatchAppendReq.Options)
_sym_db.RegisterMessage(BatchAppendReq.ProposedMessage)
_sym_db.RegisterMessage(BatchAppendReq.ProposedMessage.MetadataEntry)

BatchAppendResp = _reflection.GeneratedProtocolMessageType(
    "BatchAppendResp",
    (_message.Message,),
    {
        "Success": _reflection.GeneratedProtocolMessageType(
            "Success",
            (_message.Message,),
            {
                "DESCRIPTOR": _BATCHAPPENDRESP_SUCCESS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendResp.Success)
            },
        ),
        "DESCRIPTOR": _BATCHAPPENDRESP,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.BatchAppendResp)
    },
)
_sym_db.RegisterMessage(BatchAppendResp)
_sym_db.RegisterMessage(BatchAppendResp.Success)

DeleteReq = _reflection.GeneratedProtocolMessageType(
    "DeleteReq",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _DELETEREQ_OPTIONS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.DeleteReq.Options)
            },
        ),
        "DESCRIPTOR": _DELETEREQ,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.DeleteReq)
    },
)
_sym_db.RegisterMessage(DeleteReq)
_sym_db.RegisterMessage(DeleteReq.Options)

DeleteResp = _reflection.GeneratedProtocolMessageType(
    "DeleteResp",
    (_message.Message,),
    {
        "Position": _reflection.GeneratedProtocolMessageType(
            "Position",
            (_message.Message,),
            {
                "DESCRIPTOR": _DELETERESP_POSITION,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.DeleteResp.Position)
            },
        ),
        "DESCRIPTOR": _DELETERESP,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.DeleteResp)
    },
)
_sym_db.RegisterMessage(DeleteResp)
_sym_db.RegisterMessage(DeleteResp.Position)

TombstoneReq = _reflection.GeneratedProtocolMessageType(
    "TombstoneReq",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _TOMBSTONEREQ_OPTIONS,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.TombstoneReq.Options)
            },
        ),
        "DESCRIPTOR": _TOMBSTONEREQ,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.TombstoneReq)
    },
)
_sym_db.RegisterMessage(TombstoneReq)
_sym_db.RegisterMessage(TombstoneReq.Options)

TombstoneResp = _reflection.GeneratedProtocolMessageType(
    "TombstoneResp",
    (_message.Message,),
    {
        "Position": _reflection.GeneratedProtocolMessageType(
            "Position",
            (_message.Message,),
            {
                "DESCRIPTOR": _TOMBSTONERESP_POSITION,
                "__module__": "esdbclient.protos.Grpc.streams_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.streams.TombstoneResp.Position)
            },
        ),
        "DESCRIPTOR": _TOMBSTONERESP,
        "__module__": "esdbclient.protos.Grpc.streams_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.streams.TombstoneResp)
    },
)
_sym_db.RegisterMessage(TombstoneResp)
_sym_db.RegisterMessage(TombstoneResp.Position)

_STREAMS = DESCRIPTOR.services_by_name["Streams"]
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n%com.eventstore.dbclient.proto.streams"
    _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._options = None
    _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_options = b"8\001"
    _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._options = None
    _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_options = b"8\001"
    _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._options = None
    _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_options = b"8\001"
    _READREQ._serialized_start = 237
    _READREQ._serialized_end = 2074
    _READREQ_OPTIONS._serialized_start = 311
    _READREQ_OPTIONS._serialized_end = 2074
    _READREQ_OPTIONS_STREAMOPTIONS._serialized_start = 968
    _READREQ_OPTIONS_STREAMOPTIONS._serialized_end = 1173
    _READREQ_OPTIONS_ALLOPTIONS._serialized_start = 1176
    _READREQ_OPTIONS_ALLOPTIONS._serialized_end = 1362
    _READREQ_OPTIONS_SUBSCRIPTIONOPTIONS._serialized_start = 1364
    _READREQ_OPTIONS_SUBSCRIPTIONOPTIONS._serialized_end = 1385
    _READREQ_OPTIONS_POSITION._serialized_start = 1387
    _READREQ_OPTIONS_POSITION._serialized_end = 1448
    _READREQ_OPTIONS_FILTEROPTIONS._serialized_start = 1451
    _READREQ_OPTIONS_FILTEROPTIONS._serialized_end = 1819
    _READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION._serialized_start = 1756
    _READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION._serialized_end = 1799
    _READREQ_OPTIONS_UUIDOPTION._serialized_start = 1821
    _READREQ_OPTIONS_UUIDOPTION._serialized_end = 1938
    _READREQ_OPTIONS_CONTROLOPTION._serialized_start = 1940
    _READREQ_OPTIONS_CONTROLOPTION._serialized_end = 1978
    _READREQ_OPTIONS_READDIRECTION._serialized_start = 1980
    _READREQ_OPTIONS_READDIRECTION._serialized_end = 2024
    _READRESP._serialized_start = 2077
    _READRESP._serialized_end = 3378
    _READRESP_READEVENT._serialized_start = 2534
    _READRESP_READEVENT._serialized_end = 3166
    _READRESP_READEVENT_RECORDEDEVENT._serialized_start = 2778
    _READRESP_READEVENT_RECORDEDEVENT._serialized_end = 3154
    _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_start = 3107
    _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_end = 3154
    _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_start = 3168
    _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_end = 3219
    _READRESP_CHECKPOINT._serialized_start = 3221
    _READRESP_CHECKPOINT._serialized_end = 3284
    _READRESP_STREAMNOTFOUND._serialized_start = 3286
    _READRESP_STREAMNOTFOUND._serialized_end = 3367
    _APPENDREQ._serialized_start = 3381
    _APPENDREQ._serialized_end = 4052
    _APPENDREQ_OPTIONS._serialized_start = 3544
    _APPENDREQ_OPTIONS._serialized_end = 3808
    _APPENDREQ_PROPOSEDMESSAGE._serialized_start = 3811
    _APPENDREQ_PROPOSEDMESSAGE._serialized_end = 4041
    _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_start = 3107
    _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_end = 3154
    _APPENDRESP._serialized_start = 4055
    _APPENDRESP._serialized_end = 5220
    _APPENDRESP_POSITION._serialized_start = 1387
    _APPENDRESP_POSITION._serialized_end = 1448
    _APPENDRESP_SUCCESS._serialized_start = 4295
    _APPENDRESP_SUCCESS._serialized_end = 4545
    _APPENDRESP_WRONGEXPECTEDVERSION._serialized_start = 4548
    _APPENDRESP_WRONGEXPECTEDVERSION._serialized_end = 5210
    _BATCHAPPENDREQ._serialized_start = 5223
    _BATCHAPPENDREQ._serialized_end = 6088
    _BATCHAPPENDREQ_OPTIONS._serialized_start = 5466
    _BATCHAPPENDREQ_OPTIONS._serialized_end = 5850
    _BATCHAPPENDREQ_PROPOSEDMESSAGE._serialized_start = 5853
    _BATCHAPPENDREQ_PROPOSEDMESSAGE._serialized_end = 6088
    _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_start = 3107
    _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_end = 3154
    _BATCHAPPENDRESP._serialized_start = 6091
    _BATCHAPPENDRESP._serialized_end = 6767
    _BATCHAPPENDRESP_SUCCESS._serialized_start = 6495
    _BATCHAPPENDRESP_SUCCESS._serialized_end = 6729
    _DELETEREQ._serialized_start = 6770
    _DELETEREQ._serialized_end = 7112
    _DELETEREQ_OPTIONS._serialized_start = 3544
    _DELETEREQ_OPTIONS._serialized_end = 3808
    _DELETERESP._serialized_start = 7115
    _DELETERESP._serialized_end = 7328
    _DELETERESP_POSITION._serialized_start = 1387
    _DELETERESP_POSITION._serialized_end = 1448
    _TOMBSTONEREQ._serialized_start = 7331
    _TOMBSTONEREQ._serialized_end = 7679
    _TOMBSTONEREQ_OPTIONS._serialized_start = 3544
    _TOMBSTONEREQ_OPTIONS._serialized_end = 3808
    _TOMBSTONERESP._serialized_start = 7682
    _TOMBSTONERESP._serialized_end = 7901
    _TOMBSTONERESP_POSITION._serialized_start = 1387
    _TOMBSTONERESP_POSITION._serialized_end = 1448
    _STREAMS._serialized_start = 7904
    _STREAMS._serialized_end = 8384
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import esdbclient.protos.Grpc.code_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Status(google.protobuf.message.Message):
    """The `Status` type defines a logical error model that is suitable for
    different programming environments, including REST APIs and RPC APIs. It is
    used by [gRPC](https://github.com/grpc). Each `Status` message contains
    three pieces of data: error code, error message, and error details.

    You can find out more about this error model and how to work with it in the
    [API Design Guide](https://cloud.google.com/apis/design/errors).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    code: esdbclient.protos.Grpc.code_pb2.Code.ValueType
    """The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code]."""

    message: typing.Text
    """A developer-facing error message, which should be in English. Any
    user-facing error message should be localized and sent in the
    [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.
    """

    @property
    def details(self) -> google.protobuf.any_pb2.Any:
        """A list of messages that carry the error details.  There is a common set of
        message types for APIs to use.
        """
        pass
    def __init__(
        self,
        *,
        code: esdbclient.protos.Grpc.code_pb2.Code.ValueType = ...,
        message: typing.Text = ...,
        details: typing.Optional[google.protobuf.any_pb2.Any] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["details", b"details"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "code", b"code", "details", b"details", "message", b"message"
        ],
    ) -> None: ...

global___Status = Status



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['esdbclient', 'esdbclient.protos.Grpc']

package_data = \
{'': ['*']}

install_requires = \
['grpcio>=1.44.0,<1.45.0', 'protobuf>=3.20.0,<3.21.0', 'typing_extensions']

setup_kwargs = {
    'name': 'esdbclient',
    'version': '0.4',
    'description': 'Python gRPC Client for EventStoreDB',
    'long_description': '# Python gRPC Client for EventStoreDB\n\nThis package provides a Python gRPC client for\n[EventStoreDB](https://www.eventstore.com/). It has been\ndeveloped and tested to work with version 21.10 of EventStoreDB,\nand with Python versions 3.7, 3.8, 3.9, and 3.10.\n\nMethods have typing annotations, the static typing is checked\nwith mypy, and the test coverage is 100%.\n\nNot all the features of the EventStoreDB API are presented\nby this client in its current form, however most of the useful\naspects are presented in an easy-to-use interface (see below).\n\n## Installation\n\nUse pip to install this package from the\n[the Python Package Index](https://pypi.org/project/esdbclient/).\n\n    $ pip install esdbclient\n\nIt is recommended to install Python packages into a Python virtual environment.\n\n## Getting started\n\n### Start EventStoreDB\n\nUse Docker to run EventStoreDB from the official container image on DockerHub.\n\n    $ docker run -d --name my-eventstoredb -it -p 2113:2113 -p 1113:1113 eventstore/eventstore:21.10.2-buster-slim --insecure\n\n### Construct client\n\nThe class `EsdbClient` can be constructed with a `uri` that indicates the hostname\nand port number of the EventStoreDB server.\n\n```python\nfrom esdbclient.client import EsdbClient\n\nclient = EsdbClient(uri=\'localhost:2113\')\n```\n\n### Append events\n\nThe method `append_events()` can be used to append events to\na stream.\n\nThe arguments `stream_name`, `expected_position` and `new_events`\nare required.\n\nThe `stream_name` argument is a string that uniquely identifies\nthe stream in the database.\n\nThe `expected_position` argument is an optional integer that specifies\nthe expected position of the end of the stream in the database: either\nan integer representing the expected current position of the stream;\nor `None` if the stream is expected not to exist.\n\nThe `events` argument is a list of new event objects to be appended to the\nstream. The class `NewEvent` can be used to construct new event objects.\n\nThe method `append_events()` returns the "commit position", which is a\nmonotonically increasing integer representing the position of the recorded\nevent in a "total order" of all recorded events in all streams.\n\nIn the example below, a stream is created by appending a new event with\n`expected_position=None`.\n\n```python\nfrom uuid import uuid4\n\nfrom esdbclient.events import NewEvent\n\n# Construct new event object.\nevent1 = NewEvent(type="OrderCreated", data=b"{}", metadata=b"{}")\n\n# Define stream name.\nstream_name1 = str(uuid4())\n\n# Append list of events to new stream.\ncommit_position1 = client.append_events(\n    stream_name=stream_name1, expected_position=None, events=[event1]\n)\n```\n\nIn the example below, two subsequent events are appended to an existing\nstream. Since the stream only has one recorded event, the current position\nof the end of the stream is `0`.\n\n```python\nevent2 = NewEvent(type="OrderUpdated", data=b"{}", metadata=b"{}")\nevent3 = NewEvent(type="OrderDeleted", data=b"{}", metadata=b"{}")\n\ncommit_position2 = client.append_events(\n    stream_name1, expected_position=0, events=[event2, event3]\n)\n```\n\nPlease note, whilst the appending in one operation of a list of events\nis atomic (either all or none will be recorded), by design it is only\npossible with EventStoreDB to atomically record events in one stream.\n\n### Read stream events\n\nThe method `read_stream_events()` can be used to read the recorded\nevents in a stream. The argument `stream_name` is required. By default,\nall recorded events in the stream are returned in the order they were\nappended. An iterable object of recorded events is returned.\n\nRead all the recorded events in a stream.\n\n```python\nevents = list(client.read_stream_events(stream_name=stream_name1))\n\nassert len(events) == 3\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 0\nassert events[0].type == event1.type\nassert events[0].data == event1.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 1\nassert events[1].type == event2.type\nassert events[1].data == event2.data\n\nassert events[2].stream_name == stream_name1\nassert events[2].stream_position == 2\nassert events[2].type == event3.type\nassert events[2].data == event3.data\n```\n\nThe method `read_stream_events()` also supports three optional arguments,\n`position`, `backwards`, and `limit`.\n\nThe argument `position` is an optional integer that can be used to indicate\nthe stream position from which to start reading. This argument is `None` by default,\nmeaning that the stream will be read from the start, or from the end if `backwards`\nis `True`.\n\nThe argument `backwards` is a boolean which is by default `False` meaning the\nstream will be read forwards by default, so that events are returned in the\norder they were appended, If `backwards` is `True`, the stream will be read\nbackwards, so that events are returned in reverse order.\n\nThe argument `limit` is an integer which limits the number of events that will\nbe returned.\n\nRead recorded events in a stream from a specific stream position.\n\n```python\nevents = list(client.read_stream_events(stream_name1, position=1))\n\nassert len(events) == 2\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 1\nassert events[0].type == event2.type\nassert events[0].data == event2.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 2\nassert events[1].type == event3.type\nassert events[1].data == event3.data\n```\n\nRead the recorded events in a stream backwards from the end.\n\n```python\nevents = list(client.read_stream_events(stream_name1, backwards=True))\n\nassert len(events) == 3\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 2\nassert events[0].type == event3.type\nassert events[0].data == event3.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 1\nassert events[1].type == event2.type\nassert events[1].data == event2.data\n```\n\nRead a limited number of recorded events in stream.\n\n```python\nevents = list(client.read_stream_events(stream_name1, limit=2))\n\nassert len(events) == 2\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 0\nassert events[0].type == event1.type\nassert events[0].data == event1.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 1\nassert events[1].type == event2.type\nassert events[1].data == event2.data\n```\n\nRead a limited number of recorded events backwards from given position.\n\n```python\nevents = list(client.read_stream_events(stream_name1, position=2, backwards=True, limit=1))\n\nassert len(events) == 1\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 2\nassert events[0].type == event3.type\nassert events[0].data == event3.data\n```\n\n### Get current stream position\n\nThe method `get_stream_position()` can be used to get the current\nstream position of the last event in the stream.\n\n```python\ncurrent_position = client.get_stream_position(stream_name1)\n\nassert current_position == 2\n```\n\nThe sequence of stream positions is intended to be gapless. It is\nalso usually zero-based, so that the position of the end of the stream\nwhen one event has been appended is `0`. The position is `1` after two\nevents have been appended, `2` after three events have been appended,\nand so on.\n\nThe position of a stream that does not exist is reported by this method to\nbe `None`.\n\n```python\ncurrent_position = client.get_stream_position(stream_name="stream-unknown")\n\nassert current_position == None\n```\n\n### Read all recorded events\n\nThe method `read_all_events()` can be used to read all recorded events\nin all streams in the order they were committed. An iterable object of\nrecorded events is returned.\n\nRead events from all streams in the order they were committed.\n\n```python\nevents = list(client.read_all_events())\n\nassert len(events) >= 3\n```\n\nThe method `read_stream_events()` supports three optional arguments,\n`position`, `backwards`, and `limit`.\n\nThe argument `position` is an optional integer that can be used to indicate\nthe commit position from which to start reading. This argument is `None` by default,\nmeaning that all the events will be read from the start, or from the end if `backwards`\nis `True`. Please note, if given the commit position must be an actually existing\ncommit position, and any other numbers will result in an exception being raised.\n\nThe argument `backwards` is a boolean which is by default `False` meaning all the\nevents will be read forwards by default, so that events are returned in the\norder they were committed, If `backwards` is `True`, all the events will be read\nbackwards, so that events are returned in reverse order.\n\nThe argument `limit` is an integer which limits the number of events that will\nbe returned.\n\nPlease note, if `backwards` is used in combination with `position`, the recorded\nevent at the given commit position will NOT be included. This differs from reading\nevents from a stream backwards from a stream position, when the recorded event at\nthe given stream position WILL be included.\n\nRead recorded events in a stream from a particular position.\n\n```python\nevents = list(client.read_all_events(position=commit_position1))\n\nassert len(events) == 3\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 0\nassert events[0].type == event1.type\nassert events[0].data == event1.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 1\nassert events[1].type == event2.type\nassert events[1].data == event2.data\n\nassert events[2].stream_name == stream_name1\nassert events[2].stream_position == 2\nassert events[2].type == event3.type\nassert events[2].data == event3.data\n```\n\nRead all the recorded events backwards from the end.\n\n```python\nevents = list(client.read_all_events(backwards=True))\n\nassert len(events) >= 3\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 2\nassert events[0].type == event3.type\nassert events[0].data == event3.data\n\nassert events[1].stream_name == stream_name1\nassert events[1].stream_position == 1\nassert events[1].type == event2.type\nassert events[1].data == event2.data\n\nassert events[2].stream_name == stream_name1\nassert events[2].stream_position == 0\nassert events[2].type == event1.type\nassert events[2].data == event1.data\n```\n\nRead a limited number of recorded events from a specific commit position.\n\n```python\nevents = list(client.read_all_events(position=commit_position1, limit=1))\n\nassert len(events) == 1\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 0\nassert events[0].type == event1.type\nassert events[0].data == event1.data\n```\n\nRead a limited number of recorded events backwards from the end.\n\n```python\nevents = list(client.read_all_events(backwards=True, limit=1))\n\nassert len(events) == 1\n\nassert events[0].stream_name == stream_name1\nassert events[0].stream_position == 2\nassert events[0].type == event3.type\nassert events[0].data == event3.data\n```\n\n### Catch-up subscriptions\n\nThe method `subscribe_all_events()` can be used to create a\n"catch-up subscription" to EventStoreDB. The optional argument\n`position` can be used to specify a commit position from which\nto receive recorded events. Please note, returned events are those\nafter the given commit position.\n\nThis method returns an iterable object, a `CatchupSubscription`,\nfrom which recorded events can be obtained by iterating over the\nsubscription object.\n\nThe recorded events can be processed. The commit position of\nthe recorded event should be stored atomically with the results\nof processing the event. The value of the `position` argument can\nthen be determined by reading the recorded commit position. This\nwill accomplish "exactly once" processing of the events, from the\npoint of view of the recorded results of processing the events, so\nlong as there is a uniqueness constraint on the recorded commit\nposition.\n\n\n```python\n\n# Get the current commit position.\ncommit_position = client.get_commit_position()\n\n# Append three more events.\nstream_name = str(uuid4())\nevent1 = NewEvent(type="OrderCreated", data=b"", metadata=b"{}")\nevent2 = NewEvent(type="OrderUpdated", data=b"", metadata=b"{}")\nevent3 = NewEvent(type="OrderDeleted", data=b"", metadata=b"{}")\nclient.append_events(\n    stream_name, expected_position=None, events=[event1, event2, event3]\n)\n\n# Subscribe from the last commit position.\nsubscription = client.subscribe_all_events(position=commit_position)\n\n# Check the stream name of the newly received events.\nevents = []\nfor event in subscription:\n    assert event.stream_name == stream_name\n    events.append(event)\n    if len(events) == 3:\n        break\n\ndel subscription\n```\n\nThe `CatchupSubscription` subscription object might be used within a thread,\nwith recorded events put on a queue, for processing in a different thread.\nHowever, this client doesn\'t provide such a thing.\n\n### The NewEvent class\n\nThe `NewEvent` class can be used to define new events.\n\nThe attribute `type` is a unicode string, used to specify the type of the event\nto be recorded.\n\nThe attribute `data` is a byte string, used to specify the data of the event\nto be recorded.\n\nThe attribute `metadata` is a byte string, used to specify metadata for the event\nto be recorded.\n\n```python\nnew_event = NewEvent(\n    type="OrderCreated",\n    data=b"{}",\n    metadata=b"{}",\n)\n```\n\n### The RecordedEvent class\n\nThe `RecordedEvent` class is used when reading recorded events.\n\nThe attribute `type` is a unicode string, used to indicate the type of the event\nthat was recorded.\n\nThe attribute `data` is a byte string, used to specify the data of the event\nthat was recorded.\n\nThe attribute `metadata` is a byte string, used to specify metadata for the event\nthat was recorded.\n\nThe attribute `stream_name` is a unicode string, used to indicate the type of\nthe name of the stream in which the event was recorded.\n\nThe attribute `stream_position` is an integer, used to indicate\nthe position in the stream at which the event was recorded.\n\nThe attribute `commit_position` is an integer, used to indicate\nthe position in total order of all recorded events at which the\nevent was recorded.\n\n```python\n\nfrom esdbclient.events import RecordedEvent\n\nnew_event = RecordedEvent(\n    type="OrderCreated",\n    data=b"{}",\n    metadata=b"{}",\n    stream_name="stream1",\n    stream_position=0,\n    commit_position=512,\n)\n```\n\n### Stop EventStoreDB\n\nUse Docker to stop and remove the EventStoreDB container.\n\n    $ docker stop my-eventstoredb\n\t$ docker rm my-eventstoredb\n\n\n## Developers\n\nClone the project repository, set up a virtual environment, and install\ndependencies.\n\nUse your IDE (e.g. PyCharm) to open the project repository. Create a\nPoetry virtual environment, and then update packages.\n\n    $ make update-packages\n\nAlternatively, use the ``make install`` command to create a dedicated\nPython virtual environment for this project.\n\n    $ make install\n\nThe ``make install`` command uses the build tool Poetry to create a dedicated\nPython virtual environment for this project, and installs popular development\ndependencies such as Black, isort and pytest.\n\nAdd tests in `./tests`. Add code in `./esdbclient`.\n\nStart EventStoreDB.\n\n    $ make start-eventstoredb\n\nRun tests.\n\n    $ make test\n\nStop EventStoreDB.\n\n    $ make stop-eventstoredb\n\nCheck the formatting of the code.\n\n    $ make lint\n\nReformat the code.\n\n    $ make fmt\n\nAdd dependencies in `pyproject.toml` and then update installed packages.\n\n    $ make update-packages\n',
    'author': 'John Bywater',
    'author_email': 'john.bywater@appropriatesoftware.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pyeventsourcing/esdbclient',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: esdbclient/protos/Grpc/status.proto
"""Generated protocol buffer code."""
from google.protobuf import (
    descriptor as _descriptor,
    descriptor_pool as _descriptor_pool,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2

from esdbclient.protos.Grpc import (
    code_pb2 as esdbclient_dot_protos_dot_Grpc_dot_code__pb2,
)

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#esdbclient/protos/Grpc/status.proto\x12\ngoogle.rpc\x1a\x19google/protobuf/any.proto\x1a!esdbclient/protos/Grpc/code.proto"`\n\x06Status\x12\x1e\n\x04\x63ode\x18\x01'
    b" \x01(\x0e\x32\x10.google.rpc.Code\x12\x0f\n\x07message\x18\x02"
    b" \x01(\t\x12%\n\x07\x64\x65tails\x18\x03"
    b" \x01(\x0b\x32\x14.google.protobuf.AnyBa\n\x0e\x63om.google.rpcB\x0bStatusProtoP\x01Z7google.golang.org/genproto/googleapis/rpc/status;status\xf8\x01\x01\xa2\x02\x03RPCb\x06proto3"
)


_STATUS = DESCRIPTOR.message_types_by_name["Status"]
Status = _reflection.GeneratedProtocolMessageType(
    "Status",
    (_message.Message,),
    {
        "DESCRIPTOR": _STATUS,
        "__module__": "esdbclient.protos.Grpc.status_pb2"
        # @@protoc_insertion_point(class_scope:google.rpc.Status)
    },
)
_sym_db.RegisterMessage(Status)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n\016com.google.rpcB\013StatusProtoP\001Z7google.golang.org/genproto/googleapis/rpc/status;status\370\001\001\242\002\003RPC"
    _STATUS._serialized_start = 113
    _STATUS._serialized_end = 209
# @@protoc_insertion_point(module_scope)
